@@ -54,9 +54,9 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   # sample size
   n <- dim(X)[1]
   # compute log-likelihood
-  residuals <- object$residuals
+  residuals    <- object$residuals
   object.restr <- list(residuals = residuals, weights = weights)
-  ll.unrestr <- con_loglik_lm(object.restr)
+  ll.unrestr   <- con_loglik_lm(object.restr)
   
   
   if (debug) {
@@ -100,22 +100,50 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
     meq  <- 0L
   }
   
-  # compute the reduced row-echelon form of the constraints matrix
-  rAmat <- GaussianElimination(t(Amat))
-  if (mix.weights == "pmvnorm") {
-    if (rAmat$rank < nrow(Amat) && rAmat$rank != 0L) {
-      stop(paste("Restriktor ERROR: The constraint matrix must have full row-rank", 
-                 "\n  (choose e.g. rows", paste(rAmat$pivot, collapse = " "),")."))
-    }
-  } else if (rAmat$rank < nrow(Amat) && 
-             !(se %in% c("none", "boot.model.based", "boot.standard")) && 
-             rAmat$rank != 0L) {
-    se <- "none"
-    warning(paste("Restriktor Warning: No standard errors could be computed. 
-                    The constraint matrix must have full row-rank ( choose e.g. rows", 
-                  paste(rAmat$pivot, collapse = " "), "), 
-                    Try se = \"boot.model.based\" or \"boot.standard\"."))  
-  }
+  
+  # rAmat <- GaussianElimination(t(Amat))
+  # if (mix.weights == "pmvnorm") {
+  #   if (rAmat$rank < nrow(Amat) && rAmat$rank != 0L) {
+  #     stop(paste("Restriktor ERROR: The constraint matrix must be full row-rank.", 
+  #                "\n  There might be redundant constraints (in that case, delete those or use mix.weights = \"boot\")."))
+  #   }
+  # } else if (rAmat$rank < nrow(Amat) && 
+  #            !(se %in% c("none", "boot.model.based", "boot.standard")) && 
+  #            rAmat$rank != 0L) {
+  #   se <- "none"
+  #   warning(paste("Restriktor Warning: No standard errors could be computed. 
+  #                   The constraint matrix must be full row-rank ( choose e.g. rows", 
+  #                 paste(rAmat$pivot, collapse = " "), "), 
+  #                   Try se = \"boot.model.based\" or \"boot.standard\"."))  
+  # }
+  
+  
+  ## compute the reduced row-echelon form of the constraints matrix
+  ## remove any linear dependent rows from the constraint matrix
+  ## determine the rank of the constraint matrix
+  # if (!all(Amat == 0)) {
+  #   # remove any zero vectors
+  #   allZero.idx <- rowSums(abs(Amat)) == 0
+  #   Amat <- Amat[!allZero.idx, , drop = FALSE]
+  #   bvec <- bvec[!allZero.idx] 
+  #   rank <- qr(Amat)$rank
+  #   s <- svd(Amat)
+  #   while (rank != length(s$d)) {
+  #     # check which singular values are zero
+  #     zero.idx <- which(zapsmall(s$d) <= 1e-16)
+  #     # remove linear dependent rows and reconstruct the constraint matrix
+  #     Amat <- s$u[-zero.idx, ] %*% diag(s$d) %*% t(s$v) 
+  #     Amat <- zapsmall(Amat)
+  #     
+  #     if (all(bvec[zero.idx] != bvec[-zero.idx])) {
+  #       stop("Restriktor ERROR: conflicting constraints!") 
+  #     }
+  #      
+  #     bvec <- bvec[-zero.idx]
+  #     s <- svd(Amat)
+  #     #cat("rank = ", rank, " ... non-zero det = ", length(s$d), "\n")
+  #   }
+  # }
   
   timing$constraints <- (proc.time()[3] - start.time)
   start.time <- proc.time()[3]
@@ -134,7 +162,7 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
   if (mix.weights != "none") {
     if (nrow(Amat) == meq) {
       # equality constraints only
-      wt.bar <- rep(0L, ncol(Sigma) + 1)
+      wt.bar <- rep(0L, ncol(Sigma) + 1) 
       wt.bar.idx <- ncol(Sigma) - meq + 1
       wt.bar[wt.bar.idx] <- 1
     } else if (all(c(Amat) == 0)) { 
@@ -199,7 +227,6 @@ conLM.lm <- function(object, constraints = NULL, se = "standard",
     # compute constrained estimates using quadprog
     out.solver <- con_solver_lm(X         = X, 
                                 y         = y, 
-                                #b.unrestr = b.unrestr, 
                                 w         = weights, 
                                 Amat      = Amat,
                                 bvec      = bvec, 
