@@ -1,5 +1,7 @@
-goric <- function(object, ..., comparison = c("unconstrained", "complement", "none"), 
-                  VCOV = NULL, type = "goric", bound = NULL, debug = FALSE) {
+goric <- function(object, ..., 
+                  comparison = c("unconstrained", "complement", "none"), 
+                  VCOV = NULL, sample.nobs = NULL,
+                  type = "goric", bound = NULL, debug = FALSE) {
   
   mc <- match.call()
   CALL <- as.list(mc)
@@ -11,7 +13,7 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
   stopifnot(comparison %in% c("unconstrained", "complement", "none"))
   
   type <- tolower(type)
-  stopifnot(type %in% c("goric", "gorica"))
+  stopifnot(type %in% c("goric", "goricc", "gorica", "goricac"))
   
   ldots <- list(...)
   m.restr <- match(names(ldots), c("B", "mix.weights", "mix.bootstrap", 
@@ -22,7 +24,6 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
   } else {
     ldots2 <- ldots[m.restr == 0L]
   }  
-  
 
   if (inherits(object, "matrix")) {
     if (dim(object)[2] > 1L) {
@@ -31,26 +32,27 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
     object <- as.vector(object)
   }
   
-  
   # what is the constraint input type
   objectList  <- c(list(object), ldots2)
   isRestr     <- sapply(objectList, function(x) inherits(x, "restriktor"))
-  isCharacter <- sapply(ldots2, function(x) inherits(x, "character"))
-  isList      <- sapply(ldots2, function(x) inherits(x, "list"))
+  isCharacter <- sapply(ldots2,     function(x) inherits(x, "character"))
+  isList      <- sapply(ldots2,     function(x) inherits(x, "list"))
   
-  # output list
+  # create output list
   ans <- list()
   
   ## how to deal with constraints
   # if all objects are of class restriktor
   if (all(isRestr)) {  
-    conList <- objectList
-    isSummary <- lapply(conList, function(x) summary(x))
+    conList   <- objectList
+    isSummary <- lapply(conList, function(x) summary(x, 
+                                                     goric       = type,
+                                                     sample.nobs = sample.nobs))
     ans$model.org <- object$model.org
+    sample.nobs   <-  nrow(model.frame(object$model.org))
     # unrestricted VCOV
     VCOV <- vcov(ans$model.org)
-    
-    idx <- length(conList) 
+    idx  <- length(conList) 
     objectnames <- vector("character", idx)
     for (i in 1:idx) {
       if (length(as.character(CALL[[i]])) > 1) {
@@ -75,12 +77,14 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
     }
     # compute symmary for each restriktor object. Here is the goric value 
     # computed. Note, not the gorica value
-    isSummary <- lapply(conList, function(x) summary(x))
+    isSummary <- lapply(conList, function(x) summary(x, 
+                                                     goric       = type,
+                                                     sample.nobs = sample.nobs))
     # add unrestricted object to output
     ans$model.org <- object
     # unrestricted VCOV
     VCOV <- vcov(ans$model.org)
-    
+    sample.nobs <- nrow(model.frame(object))
     idx <- length(conList) 
     objectnames <- vector("character", idx)
     CALL$object <- NULL
@@ -119,12 +123,14 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
       }
       # compute symmary for each restriktor object. Here is the goric value 
       # computed. Note, not the gorica value
-      isSummary <- lapply(conList, function(x) summary(x))
+      isSummary <- lapply(conList, function(x) summary(x, 
+                                                       goric       = type,
+                                                       sample.nobs = sample.nobs))
       # add unrestricted object to output
       ans$model.org <- object
       # unrestricted VCOV
       VCOV <- vcov(ans$model.org)
-      
+      sample.nobs <- nrow(model.frame(object))
       idx <- length(conList) 
       objectnames <- vector("character", idx)
       CALL$object <- NULL
@@ -135,12 +141,15 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
         objectnames[i] <- as.character(CALL[[i]])
       }
     } else if (inherits(object, "numeric")) {
-      if (type == "goric") {
-        stop("Restriktor ERROR: object of class numeric is only supported for type = 'gorica'.")
+      if (type %in% c("goric", "goricc")) {
+        stop("Restriktor ERROR: object of class numeric is only supported for type = 'goric(c)a'.")
       }
       if (is.null(VCOV)) {
         stop("Restriktor ERROR: the argument VCOV is not found.")
       }
+      if (is.null(sample.nobs) && type %in% c("goricc", "goricac")) {
+        stop("Restriktor ERROR: the argument sample.nobs is not found.")
+      }
       
       isCharacter <- sapply(ldots2, function(x) inherits(x, "character"))    
       isList      <- sapply(ldots2, function(x) inherits(x, "list"))
@@ -150,10 +159,10 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
         # create lists
         #constraints <- list(); rhs <- list(); neq <- list()
         # extract constraints, rhs and neq
-        constraints <- lapply(ldots2, FUN = function(x) { x$constraints } )
-        constraints.check <- sapply(constraints, FUN = function(x) { is.null(x) } )
-        if (any(constraints.check)) {
-          stop("Restriktor ERROR: the constraints must be specified as a list. E.g., h1 <- list(constraints = 'x1 > 0')")
+        constraints       <- lapply(ldots2,      FUN = function(x) { x$constraints } )
+        constraints.check <- sapply(constraints, FUN = function(x) { is.null(x)} )
+        if (any(constraints.check) || length(constraints) == 0) {
+          stop("Restriktor ERROR: no constraints found! The constraints must be specified as a list. E.g., h1 <- list(constraints = 'x1 > 0')")
         }
         rhs <- lapply(ldots2, FUN = function(x) {x$rhs} )
         neq <- lapply(ldots2, FUN = function(x) {x$neq} )
@@ -169,9 +178,11 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
                           ldots3)
           conList[[c]] <- do.call("con_gorica_est", CALL.restr) 
         }
-        isSummary <- lapply(conList, function(x) summary(x))
+        isSummary <- lapply(conList, function(x) summary(x, 
+                                                         type        = type,
+                                                         sample.nobs = sample.nobs)) 
       } else if (all(isCharacter)) {
-        # if constraints is character
+        # if constraints is character 
         constraints <- ldots2[isCharacter]
         # fit restriktor object for each hypothesis
         conList <- list()
@@ -182,14 +193,16 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
                           ldots3)
           conList[[c]] <- do.call("con_gorica_est", CALL.restr)  
         }
-        isSummary <- lapply(conList, function(x) summary(x))
+        isSummary <- lapply(conList, function(x) summary(x, 
+                                                         type        = type,
+                                                         sample.nobs = sample.nobs))
       }
       CALL$object <- NULL; CALL$comparison <- NULL; CALL$type <- NULL
       CALL$VCOV <- NULL; CALL$bound <- NULL; 
       CALL$debug <- NULL; CALL$B <- NULL; CALL$mig.weights <- NULL; 
       CALL$mix.bootstrap <- NULL; CALL$parallel <- NULL; CALL$ncpus <- NULL; 
       CALL$cl <- NULL; CALL$seed <- NULL; CALL$control <- NULL; 
-      CALL$verbose <- NULL; #CALL[[1]] <- NULL
+      CALL$verbose <- NULL; 
       
       idx <- length(conList) 
       objectnames <- vector("character", idx)
@@ -200,7 +213,7 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
         objectnames[i] <- as.character(CALL[[i]])
       }
     } else {
-      stop("Restriktor ERROR: I don't know how to handle the constraints.")
+      stop("Restriktor ERROR: I don't know how to handle an object of class ", paste0(class(object)[1]))
     }
 
 
@@ -457,12 +470,11 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
       }
       ## compute log-likelihood for complement
       # check if any constraint is violated
-      if (check.ciq || check.ceq) {   
-        #llc <- con_loglik_lm(ans$model.org)
-        if (type == "goric") {
+      if (check.ciq || check.ceq) {    
+        if (type %in% c("goric", "goricc")) { 
           llc <- logLik(ans$model.org)
           betasc <- b.unrestr
-        } else if (type == "gorica") {
+        } else if (type %in% c("gorica", "goricac")) {
           llc <- dmvnorm(rep(0, p), sigma = VCOV, log = TRUE)
           betasc <- b.unrestr
         }
@@ -484,13 +496,13 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
         for (l in 1:length(nr)) {
           idx <- c(nr[l], nr[-l])
           Amatx <- Amat[idx, , drop = FALSE]
-          if (type == "goric") {          
+          if (type %in% c("goric", "goricc")) {          
             Hc.restr <- restriktor(ans$model.org, constraints = Amatx, 
                                    neq = 1, rhs = bvec[idx], 
                                    mix.weights = "none", se = "none")
             betas[[l]] <- coef(Hc.restr)
-            ll[[l]] <- logLik(Hc.restr)
-          } else if (type == "gorica") {
+            ll[[l]]    <- logLik(Hc.restr)
+          } else if (type %in% c("gorica", "goricac")) {
             ldots4 <- ldots[m.restr > 0L]
             ldots4$mix.weights <- "none"
             CALL.restr <- c(list(object      = b.unrestr,
@@ -499,28 +511,27 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
                                  neq         = 1,
                                  VCOV        = VCOV),
                             ldots4)
-            Hc.restr <- do.call("con_gorica_est", CALL.restr) 
+            Hc.restr   <- do.call("con_gorica_est", CALL.restr) 
             betas[[l]] <- Hc.restr$b.restr
-            ll[[l]] <- dmvnorm(c(b.unrestr - Hc.restr$b.restr), sigma = VCOV, log = TRUE)            
+            ll[[l]]    <- dmvnorm(c(b.unrestr - Hc.restr$b.restr), 
+                                  sigma = VCOV, log = TRUE)            
           }
         }
         if (debug) {
           cat("log-likelihood value =", ll[[l]], "\n")
         }
-        # take the highest log-likelihood value as a substitute for 
-        # the complement
+        # take the highest log-likelihood value as a substitute for the complement
         ll.unlist <- unlist(ll)
         ll.idx <- which(ll.unlist == max(ll.unlist))
         llc <- max(ll.unlist)
-        betasc <- betas[[ll.idx]]#data.frame(matrix(unlist(betas), nrow=length(betas), byrow=TRUE))
+        betasc <- betas[[ll.idx]]
       } else if (nrow(Amat) == meq) { 
-        # redundant, this will be catched by the first statement.
-        # in case of equality constraints only, the complement is 
-        # equal to the unconstrained log-likelihood
-        if (type == "goric") {
+        # redundant, this will be catched by the first statement. In case of equality 
+        # constraints only, the complement is equal to the unconstrained log-likelihood
+        if (type %in% c("goric", "goricc")) {
           llc <- logLik(ans$model.org)
           betasc <- b.unrestr
-        } else if (type == "gorica") {
+        } else if (type %in% c("gorica", "goricac")) {
           llc <- dmvnorm(rep(0, p), sigma = VCOV, log = TRUE)
           betasc <- b.unrestr
         }
@@ -533,41 +544,50 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
       } else {
         stop("Restriktor ERROR: you might have found a bug, please contact me!")
       }
-      #llm <- unlist(lapply(isSummary, function(x) attr(x$goric, "loglik"))) 
-      if (type == "goric") {
+      if (type %in% c("goric", "goricc")) {
         llm <- logLik(conList[[1]])
-      } else if (type == "gorica") {
+      } else if (type %in% c("gorica", "goricac")) {
         llm <- dmvnorm(c(b.unrestr - b.restr), sigma = VCOV, log = TRUE)
       }
     } 
     
     # compute the number of free parameters f in the complement
-    p <- ncol(VCOV)#length(b.unrestr)
+    p   <- ncol(VCOV)
     # rank q1
     lq1 <- qr(Amat.ciq)$rank
     # rank q2
     lq2 <- qr(Amat.ceq)$rank
     # free parameters. Note that Amat includes q1 and q2 constraints
-    f <- p - qr(Amat)$rank # p - q1 - q2
+    f   <- p - qr(Amat)$rank # p - q1 - q2
     if (debug) { cat("number of free parameters =", (f + lq2), "\n") }
+    
     # compute penalty term value PTc
-    if (type == "goric") {
+    if (type %in% c("goric", "gorica")) {
       idx <- length(wt.bar)
       if (attr(wt.bar, "method") == "boot") {
         PTc <- as.numeric(1 + p - wt.bar[idx-meq] * lq1)
       } else if (attr(wt.bar, "method") == "pmvnorm") {
-        # the q2 equalities are not included in wt.bar. Hence, do not have to be subtracted.
-        PTc <- as.numeric(1 + p - wt.bar[idx] * lq1)
+        # here, the q2 equalities are not included in wt.bar. Hence, they do not 
+        # have to be subtracted.
+        PTc <- as.numeric(1 + p - wt.bar[idx] * lq1)                            # CHECK for meq!!!
       } else {
         stop("Restriktor ERROR: no level probabilities (chi-bar-square weights) found.")
       }
-    } else if (type == "gorica") {
-      #wt.bar <- con_weights(cov = Amat %*% VCOV %*% t(Amat), meq = meq)
-      wt.bar <- conList[[1]]$wt.bar
-      idx <- length(wt.bar)
-      PTc <- as.numeric(1 + p - wt.bar[idx] * lq1)
+    } else if (type %in% c("goricc", "goricac")) {
+      idx <- length(wt.bar) 
+      if (is.null(sample.nobs)) {
+        stop("Restriktor ERROR: the argument sample.nobs is not found.")
+      }
+      N <- sample.nobs
+      # small sample correction
+     if (attr(wt.bar, "method") == "boot") {
+       PTc <- 1 + wt.bar[idx-meq] * (N * (p - lq1) + (p - lq1) + 2) / (N - (p - lq1) - 2) + 
+         (1 - wt.bar[idx-meq]) * (N * p + p + 2) / (N - p - 2)
+     } else if (attr(wt.bar, "method") == "pmvnorm") {
+        PTc <- 1 + wt.bar[idx] * (N * (p - lq1) + (p - lq1) + 2) / (N - (p - lq1) - 2) + 
+          (1 - wt.bar[idx]) * (N * p + p + 2) / (N - p - 2) 
+        }
     }
-    
     if (debug) {
       cat("penalty term value =", PTc, "\n")
     }
@@ -576,17 +596,16 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
   # compute loglik-value, goric(a)-values, and PT-values
   if (comparison == "unconstrained") { 
     PTm <- unlist(lapply(isSummary, function(x) attr(x$goric, "penalty")))
-    PTu <- 1 + ncol(VCOV)
-    if (type == "goric") {
+    if (type %in% c("goric", "goricc")) {
       # model
       llm <- unlist(lapply(isSummary, function(x) attr(x$goric, "loglik"))) 
       # unrestricted
       llu <- logLik(ans$model.org)
-    } else if (type == "gorica") {
+    } else if (type %in% c("gorica", "goricac")) {
       # model 
       if (inherits(object, "numeric")) {
         llm <- unlist(lapply(conList, function(x) dmvnorm(c(x$b.unrestr - x$b.restr), 
-                                                             sigma = VCOV, log = TRUE) )) 
+                                                            sigma = VCOV, log = TRUE) )) 
         # unrestricted
         llu <- dmvnorm(rep(0, ncol(VCOV)), sigma = VCOV, log = TRUE) 
       } else { 
@@ -596,6 +615,17 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
         llu <- dmvnorm(rep(0, ncol(VCOV)), sigma = VCOV, log = TRUE) 
       }
     }
+    
+    if (type %in% c("goric", "gorica")) {
+      PTu <- 1 + ncol(VCOV)
+    } else if (type %in% c("goricc", "goricac")) {
+      if (is.null(sample.nobs)) {
+        stop("Restriktor ERROR: the argument sample.nobs is not found.")
+      }
+      N   <- sample.nobs
+      PTu <- ( (N * (ncol(VCOV) + 1) / (N - ncol(VCOV) - 2) ) ) 
+    }
+    
     goric.Hm <- -2*(llm - PTm)
     goric.Hu <- -2*(llu - PTu)
     df.Hm <- data.frame(model = objectnames, loglik = llm, penalty = PTm, 
@@ -604,26 +634,23 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
     df.u <- data.frame(model = "unconstrained", loglik = llu, penalty = PTu, 
                        goric = goric.Hu)
     df <- rbind(df.Hm, df.u)
-    if (type == "gorica") {
-      names(df)[4] <- "gorica"
-    }
+    names(df)[4] <- type
   } else if (comparison == "none") {
     PT <- unlist(lapply(isSummary, function(x) attr(x$goric, "penalty")))
-    if (type == "goric") {
-      ll    <- unlist(lapply(isSummary, function(x) attr(x$goric, "loglik"))) 
+    if (type %in% c("goric", "goricc")) {
+      ll <- unlist(lapply(isSummary, function(x) attr(x$goric, "loglik"))) 
       goric.Hm <- unlist(lapply(isSummary, function(x) x$goric[1]))
       df <- data.frame(model = objectnames, loglik = ll, penalty = PT, 
                        goric = goric.Hm)
       df$model <- as.character(df$model)
-    } else if (type == "gorica") {
-      if (inherits(object, "numeric")) {
+    } else if (type %in% c("gorica", "goricac")) {
+#      if (inherits(object, "numeric")) {
         ll <- unlist(lapply(conList, function(x) dmvnorm(c(x$b.unrestr - x$b.restr), 
-                                                          sigma = VCOV, log = TRUE) )) 
-      } else { 
-        ll <- unlist(lapply(conList, function(x) dmvnorm(c(x$b.unrestr - x$b.restr), 
-                                                            sigma = VCOV, 
-                                                            log = TRUE) )) 
-      }
+                                                           sigma = VCOV, log = TRUE) )) 
+      # } else { 
+      #   ll <- unlist(lapply(conList, function(x) dmvnorm(c(x$b.unrestr - x$b.restr), 
+      #                                                      sigma = VCOV, log = TRUE) )) 
+      # }
       goric.Hm <- -2*(ll - PT)
       df <- data.frame(model = objectnames, loglik = ll, penalty = PT, 
                        gorica = goric.Hm)
@@ -631,7 +658,7 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
     }
   } else if (comparison == "complement") {
     PTm <- unlist(lapply(isSummary, function(x) attr(x$goric, "penalty")))
-    if (type == "goric") {
+    if (type %in% c("goric", "goricc")) {
       # model
       goric.Hm <- -2*(llm - PTm)
       df.Hm  <- data.frame(model = objectnames, loglik = llm, penalty = PTm, 
@@ -642,7 +669,7 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
       df.c  <- data.frame(model = "complement", loglik = llc, penalty = PTc, 
                           goric = goric.Hc)
       df <- rbind(df.Hm, df.c)
-    } else if (type == "gorica") {
+    } else if (type %in% c("gorica", "goricac")) {
       # model
       gorica.Hm <- -2*(llm - PTm)
       df.Hm  <- data.frame(model = objectnames, loglik = llm, penalty = PTm, 
@@ -655,7 +682,7 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
       df <- rbind(df.Hm, df.c)
     }
   } else {
-    stop("Restriktor ERROR: I cannot compute GORIC(A)-values.")
+    stop("Restriktor ERROR: I cannot compute goric-values.")
   }
 
   ans$objectList  <- conList
@@ -664,9 +691,8 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
   delta <- df$goric - min(df$goric)
   goric.weights <- exp(-delta / 2) / sum(exp(-delta / 2))
   df$goric.weights <- goric.weights
-  if (type == "gorica") {
-   names(df)[5] <- "gorica.weights" 
-  }
+    names(df)[5] <- paste0(type, ".weights")
+  
   ans$result <- df
   
 
@@ -674,6 +700,8 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
   modelnames <- as.character(df$model)
   if (length(modelnames) > 1) {
     rw <- goric.weights %*% t(1/goric.weights)
+    # it might happen that a diagonal value results in NaN.
+    diag(rw) <- 1
     rownames(rw) <- modelnames
     colnames(rw) <- paste0("vs ", modelnames)
     ans$relative.gw <- rw
@@ -710,9 +738,9 @@ goric <- function(object, ..., comparison = c("unconstrained", "complement", "no
   ans$comparison <- comparison
   ans$type <- type
   
-  if (type == "goric") {
+  if (type %in% c("goric", "goricc")) {
     class(ans) <- "goric"
-  } else if (type == "gorica") {
+  } else if (type %in% c("gorica", "goricac")) {
     class(ans) <- c("gorica", "goric")
   }
   
@@ -734,10 +762,15 @@ print.goric <- function(x, digits = max(3, getOption("digits") - 4), ...) {
   cat(sprintf("restriktor (%s): ", packageDescription("restriktor", fields = "Version")))
 
   if (type == "goric") {
-    cat("generalized order-restriced information criterion (GORIC):\n")
+    cat("\nRestriktor: generalized order-restriced information criterion: \n")
   } else if (type == "gorica") {
-    cat("generalized order-restriced information criterion approximation (GORICA):\n")
+    cat("\nRestriktor: generalized order-restriced information criterion approximation:\n")
+  } else if (type == "goricc") {
+    cat("\nRestriktor: small sample generalized order-restriced information criterion:\n")
+  } else if (type == "goricac") {
+    cat("\nRestriktor: small sample generalized order-restriced information criterion approximation:\n")
   }
+  
   cat("\nResults:\n")
   
   print(format(df, digits = digits, scientific = FALSE), 
@@ -767,8 +800,8 @@ summary.goric <- function(object, brief = TRUE,
   df <- as.data.frame(x2)
   df <- df[, c(5,1,2,3,4)]
   
-  objectnames <- as.character(df$model)
-  goric.weights <- as.numeric(as.character(df$goric.weights))
+  objectnames   <- as.character(df$model)
+  #goric.weights <- as.numeric(as.character(df$goric.weights))
 
   Amat <- x$constraints
   meq  <- x$neq
@@ -776,10 +809,15 @@ summary.goric <- function(object, brief = TRUE,
   iact <- lapply(x$objectList, FUN = function(x) { x$iact } )
 
   if (type == "goric") {
-    cat("\nRestriktor: generalized order-restriced information criterion (GORIC): \n")
+    cat("\nRestriktor: generalized order-restriced information criterion: \n")
   } else if (type == "gorica") {
-    cat("\nRestriktor: generalized order-restriced information criterion approximation (GORICA):\n")
+    cat("\nRestriktor: generalized order-restriced information criterion approximation:\n")
+  } else if (type == "goricc") {
+    cat("\nRestriktor: small sample generalized order-restriced information criterion:\n")
+  } else if (type == "goricac") {
+    cat("\nRestriktor: small sample generalized order-restriced information criterion approximation:\n")
   }
+  
   cat("\nResults:\n")  
   
   print(format(df, digits = digits, scientific = FALSE), 
@@ -793,12 +831,13 @@ summary.goric <- function(object, brief = TRUE,
       cat("\n\nRelative GORICA-weights:\n")
     }
     relative.gw <- apply(x$relative.gw, 2, sprintf, fmt = dig)
+    
     rownames(relative.gw) <- rownames(x$relative.gw)
     if (max(as.numeric(relative.gw)) >= 1e4) {
       print(format(x$relative.gw, digits = digits, scientific = TRUE), 
             print.gap = 2, quote = FALSE)
     } else {
-      print(format(relative.gw, digits = digits, scientific = FALSE), 
+      print(format(trimws(relative.gw), digits = digits, scientific = FALSE), 
             print.gap = 2, quote = FALSE)
     }
     cat("---\n")
@@ -806,7 +845,7 @@ summary.goric <- function(object, brief = TRUE,
       cat("Note: In case of equal log-likelihood (loglik) values, the 
       relative weights are solely based on the difference in penalty values.\n")
     }
-    }
+  }
   
   if (comparison == "complement") {
     cat("The order-restricted hypothesis", sQuote(objectnames[1]), "has", 
@@ -815,13 +854,13 @@ summary.goric <- function(object, brief = TRUE,
   
   if (!brief) {
     cat("\n\nOrder/Inequality restricted coefficients:\n")
-    coefs <- apply(x$ormle$b.restr, 2, sprintf, fmt = dig)
+    coefs <- trimws(apply(x$ormle$b.restr, 2, sprintf, fmt = dig))
     rownames(coefs) <- rownames(x$ormle$b.restr)
     print(format(coefs, digits = digits, scientific = FALSE), print.gap = 2L,
           quote = FALSE)
     cat("---\n")
     
-    vnames <- names(coef(x$model.org))
+    vnames <- names(x$ormle$b.restr)
     fn <- function(Amat, bvec, meq, iact, vnames) {
       colnames(Amat) <- vnames
       out.rest <- cbind(round(Amat, 4), c(rep("   ==", meq), rep("   >=", nrow(Amat) - 
